package org.silverpeas.mobile.client.apps.documents.resources;

public class DocumentsMessages_en implements org.silverpeas.mobile.client.apps.documents.resources.DocumentsMessages {
  
  public java.lang.String title() {
    return "Documents";
  }
  
  public java.lang.String lastUpdate(java.lang.String arg0,java.lang.String arg1) {
    return "Last modified on " + arg0 + " by " + arg1;
  }
  
  public java.lang.String publicationTitle() {
    return "Publication";
  }
  
  public java.lang.String sizeK(java.lang.String arg0) {
    return arg0 + " Ko";
  }
  
  public java.lang.String sizeM(java.lang.String arg0) {
    return arg0 + " Mo";
  }
  
  public java.lang.String content() {
    return "Content";
  }
  
  public java.lang.String creation(java.lang.String arg0,java.lang.String arg1) {
    return "Created on  " + arg0 + " by " + arg1;
  }
  
  public java.lang.String views(int arg0) {
    return "" + arg0 + " access";
  }
  
  public java.lang.String view() {
    return "One access";
  }
  
  public java.lang.String noview() {
    return "No access";
  }
  
  public java.lang.String share() {
    return "Share";
  }
  
  public java.lang.String validityPermanent() {
    return "Permanent";
  }
  
  public java.lang.String validityTemporary() {
    return "Temporary";
  }
  
  public java.lang.String validityMandatory() {
    return "End of validity is mandatory !";
  }
  
  public com.google.gwt.safehtml.shared.SafeHtml validityLabel() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("Validity").toSafeHtml();
  }
  
  public com.google.gwt.safehtml.shared.SafeHtml endValidityLabel() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("End validity date").toSafeHtml();
  }
  
  public com.google.gwt.safehtml.shared.SafeHtml maxAccessLabel() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("Max access number").toSafeHtml();
  }
  
  public com.google.gwt.safehtml.shared.SafeHtml usersLabel() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("Users").toSafeHtml();
  }
  
  public com.google.gwt.safehtml.shared.SafeHtml emailsLabel() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("Externals emails").toSafeHtml();
  }
  
  public com.google.gwt.safehtml.shared.SafeHtml commentsLabel() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("Additional message").toSafeHtml();
  }
  
  public java.lang.String importFile() {
    return "File import";
  }
  
  public java.lang.String maxUploadError() {
    return "Media too large";
  }
  
  public java.lang.String fileNotSupportedError() {
    return "Unsupported format";
  }
  
  public java.lang.String draftOut() {
    return "Publish";
  }
  
  public java.lang.String edit() {
    return "Edit";
  }
}
